/* Created by Anjuta version 1.0.1 */
/*	This file will not be overwritten */

#include <stdio.h>
#include <argp.h>
/** 
 * @brief Wizhctl board user interface for measure mode.
 * 
 * @file main.c
 * @author ch'gans <chgans@tuxfamily.org>
 * @date 30 sept 2003
 * @version $Id: position.c,v 1.1 2003/10/06 00:23:43 chgans Exp $ 
 * \par License:
 * Copyright (C) WISIRC <http://wisirc.tuxfamily.org>\n
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#include "linux/ioctl.h"

//#include "hctl1100.h"

#define DEFAULT_CONSIGNE	100
#define DEFAULT_PERIOD		1
#define DEFAULT_NBSAMPLE	200
#define DEFAULT_DEVICE		"/dev/hctl"

#define AUTHOR_STR		"Ch'Gans"
#define AUTHOR_EMAIL_STR	"<chagns@tuxfamily.org>"

#define __STR(arg) #arg
#define STR(arg) __STR(arg)

const char *package_name =	STR(PACKAGE);
const char *package_version =	STR(VERSION);
const char *program_name =	STR(PROGRAM);
const char *program_version =	STR(PGVERSION);
const char *bug_address =	AUTHOR_EMAIL_STR;
const char *author =		AUTHOR_STR;


/** @name argp stuff */
/**@{*/

/** Program documentation. */
static char doc[] =
  "User interface for directes measures feature of wizhctl driver";

/** Description of the arguments we accept. */
static char args_doc[] = "";

/** Options we understand. */
static struct argp_option options[] = {
  {"verbose",	'v',	0,		0,	"Produce verbose output" },
  {"quiet",	'q',	0,		0,	"Don't produce any output" },
  {"silent",	's',	0,		OPTION_ALIAS },
  {"output",	'o',	"FILE",		0,	"Output to FILE.data and FILE.time instead of standard output" },
  {"period",	'p',	"PERIOD",	0,	"Set period of measures points to PERIOD ms (default = " STR(DEFAULT_PERIOD) ")"},
  {"consigne",	'c',	"'+/-CONS'",	0,	"Set the PWM consigne to +/-CONS% (default = " STR(DEFAULT_CONSIGNE) ")"},
  {"nbsample",	'n',	"N",		0,	"Set the number of samples to N (default = " STR(DEFAULT_NBSAMPLE) ")" },
  {"device",	'd',	"DEVICE",	0,	"Use DEVICE to access HCTL board (default = " DEFAULT_DEVICE ")" },
  { 0 }
};

/** Structure used by main to communicate with parse_opt. */
struct arguments
{
  int silent, verbose;
  unsigned long period;
  short int consigne;
  unsigned short nbsample;
  char *output_file;
  char *device;
};

/** Single option parser. */
static error_t parse_opt (int key, char *arg, struct argp_state *state)
{
  /* Get the input argument from argp_parse, which we
     know is a pointer to our arguments structure. */
  struct arguments *arguments = state->input;

  switch (key)
    {
    case 'q': case 's':
      arguments->silent = 1;
      break;
    case 'v':
      arguments->verbose = 1;
      break;
    case 'o':
      arguments->output_file = arg;
      break;

    case 'p':
      sscanf(arg, "%lu", &arguments->period);
      break;

    case 'c':
      sscanf(arg, "%hd", &arguments->consigne);
      break;

    case 'n':
      sscanf(arg, "%hu", &arguments->nbsample);
      break;

    case 'd':
      printf("%s\n", arg);
      arguments->device = arg;
      break;

    case ARGP_KEY_ARG:
      if (state->arg_num > 0)
        /* Too many arguments. */
        argp_usage (state);
      break;

    case ARGP_KEY_END:
      if (state->arg_num < 0)
        /* Not enough arguments. */
        argp_usage (state);
      break;

    default:
      return ARGP_ERR_UNKNOWN;
    }
  return 0;
}

/** The argp parser. */
static struct argp argp = { options, parse_opt, args_doc, doc };

/**@}*/


/** The wizhctl measure struct. */
typedef struct _wizhctl_measure_t {
  unsigned int nb_mesures;
  unsigned int periode;
  char consigne;
  unsigned long *data;
  struct timeval *time;
} wizhctl_measure_t;

wizhctl_measure_t measure;

int main(int argc, char **argv)
{
  struct arguments args;
  int fd;

  /* Default values. */
  args.silent = 0;
  args.verbose = 0;
  args.output_file = "-";
  args.period = DEFAULT_PERIOD;
  args.nbsample = DEFAULT_NBSAMPLE;
  args.consigne = DEFAULT_CONSIGNE;
  args.device = DEFAULT_DEVICE;

  /* Parse our arguments; every option seen by parse_opt will
     be reflected in arguments. */
  argp_parse (&argp, argc, argv, 0, 0, &args);

  printf ("OUTPUT_FILE = %s\n"
          "VERBOSE = %s\nSILENT = %s\n"
	  "PERIOD=%lu\nNBSAMPLE=%hu\nCONSIGNE=%hd\n"
	  "DEVICE=%s\n",
          args.output_file,
          args.verbose ? "yes" : "no",
          args.silent ? "yes" : "no",
	  args.period,
	  args.nbsample,
	  args.consigne,
	  args.device);

  printf("%s\n", STR(KERNEL_INCLUDE));

  fd = open(args.device,  O_RDWR | O_SYNC);
  if (fd <= 0) {
    perror(args.device);
    exit(-1);
  }


  return 0;
}

#if 0
  printf ("ARG1 = %s\nARG2 = %s\nOUTPUT_FILE = %s\n"
          "VERBOSE = %s\nSILENT = %s\n",
          arguments.args[0], arguments.args[1],
          arguments.output_file,
          arguments.verbose ? "yes" : "no",
          arguments.silent ? "yes" : "no");



  int fd;
  struct hctl_param hparm;
  int reg;
  unsigned char data;
  int i,n;
  char cmdvelo[100];
  char input[20];
  char* tail;

  struct timeval *time;
  unsigned long *data;
  ident_arg_t ident;



  fd = open("/dev/hctl",  O_RDWR | O_SYNC);

  if (fd <= 0)
    {
      perror("Error opening /dev/hctl");
      exit(-1);
    }


  if (ioctl(fd, HCTL_IOC_IDENTIFICATION, &ident) < 0)
    {
      perror("Identification failed!");
      close(fd);
      exit(-1);
    }

  return 0;
}
#endif

